@@ -46,7 +46,7 @@
 	 GNOME_VFS_FILE_INFO_GET_ACCESS_RIGHTS)
 
 #define NAUTILUS_FILE_DEFAULT_ATTRIBUTES				\
-	"standard::*,access::*,mountable::*,time::*,unix::*,owner::*,selinux::*,thumbnail::*"
+	"standard::*,access::*,mountable::*,time::*,unix::*,owner::*,selinux::*,thumbnail::*,id::filesystem,trash::orig-path"
 
 /* These are in the typical sort order. Known things come first, then
  * things where we can't know, finally things where we don't yet know.
@@ -107,7 +107,6 @@ struct NautilusFileDetails
 	char *thumbnail_path;
 	GdkPixbuf *thumbnail;
 	time_t thumbnail_mtime;
-	int thumbnail_size; /* 0 means original unframed thumbnail */
 	
 	GList *mime_list; /* If this is a directory, the list of MIME types in it. */
 	char *top_left_text;
@@ -116,6 +115,13 @@ struct NautilusFileDetails
 	char *custom_icon;
 	GFile *activation_location;
 
+	/* used during DND, for checking whether source and destination are on
+	 * the same file system.
+	 */
+	eel_ref_str filesystem_id;
+
+	char *trash_orig_path;
+
 	/* The following is for file operations in progress. Since
 	 * there are normally only a few of these, we can move them to
 	 * a separate hash table or something if required to keep the
@@ -182,6 +188,7 @@ struct NautilusFileDetails
 	eel_boolean_bit got_custom_activation_location : 1;
 
 	eel_boolean_bit thumbnail_is_up_to_date       : 1;
+	eel_boolean_bit thumbnail_wants_original      : 1;
 	eel_boolean_bit thumbnail_tried_original      : 1;
 	eel_boolean_bit thumbnailing_failed           : 1;
 	
