@@ -34,7 +34,6 @@
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-util.h>
 
 /* Constants */
 #define STRING_ARRAY_DEFAULT_TOKENS_DELIMETER ","
@@ -432,7 +431,12 @@ static const PreferenceDefault preference_defaults[] = {
 	  PREFERENCE_INTEGER,
 	  GINT_TO_POINTER (96)
 	},
-
+	{ NAUTILUS_PREFERENCES_ICON_VIEW_TEXT_ELLIPSIS_LIMIT,
+	  PREFERENCE_STRING_ARRAY,
+	  "3",
+	  NULL,NULL,
+	  NULL,
+	},
 	/* Compact Icon View Default Preferences */
 	{ NAUTILUS_PREFERENCES_COMPACT_VIEW_DEFAULT_ZOOM_LEVEL,
 	  PREFERENCE_STRING,
@@ -533,6 +537,10 @@ static const PreferenceDefault preference_defaults[] = {
 	  PREFERENCE_STRING_ARRAY,
 	  "", NULL, NULL, NULL
 	},	
+	{ NAUTILUS_PREFERENCES_DESKTOP_TEXT_ELLIPSIS_LIMIT,
+	  PREFERENCE_INTEGER,
+	  GINT_TO_POINTER (3)
+	},
 	{ NULL }
 };
 
