@@ -28,10 +28,9 @@
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
-#include <eel/eel-mount-operation.h>
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 #include <string.h>
-#include <unistd.h>
 
 #include "nautilus-file-attributes.h"
 #include "nautilus-file.h"
@@ -59,7 +58,8 @@ typedef struct {
 } ApplicationLaunchParameters;
 
 typedef struct {
-	NautilusWindowInfo *window_info;
+	NautilusWindowSlotInfo *slot_info;
+	gpointer window_info;
 	GtkWindow *parent_window;
 	GCancellable *cancellable;
 	GList *files;
@@ -72,6 +72,7 @@ typedef struct {
 	NautilusFileListHandle *files_handle;
 	gboolean tried_mounting;
 	char *activation_directory;
+	gboolean user_confirmation;
 } ActivateParameters;
 
 /* Number of seconds until cancel dialog shows up */
@@ -910,8 +911,8 @@ activation_parameters_free (ActivateParameters *parameters)
 		eel_timed_wait_stop (cancel_activate_callback, parameters);
 	}
 	
-	if (parameters->window_info) {
-		g_object_remove_weak_pointer (G_OBJECT (parameters->window_info), (gpointer *)&parameters->window_info);
+	if (parameters->slot_info) {
+		g_object_remove_weak_pointer (G_OBJECT (parameters->slot_info), (gpointer *)&parameters->slot_info);
 	}
 	if (parameters->parent_window) {
 		g_object_remove_weak_pointer (G_OBJECT (parameters->parent_window), (gpointer *)&parameters->parent_window);
@@ -955,24 +956,43 @@ activation_start_timed_cancel (ActivateParameters *parameters)
 }
 
 static void
-activate_mount_op_active (EelMountOperation *operation,
-			  gboolean is_active,
+pause_activation_timed_cancel (ActivateParameters *parameters)
+{
+	if (parameters->timed_wait_active) {
+		eel_timed_wait_stop (cancel_activate_callback, parameters);
+		parameters->timed_wait_active = FALSE;
+	}
+}
+
+static void
+unpause_activation_timed_cancel (ActivateParameters *parameters)
+{
+	if (!parameters->timed_wait_active) {
+		activation_start_timed_cancel (parameters);
+	}
+}
+
+
+static void
+activate_mount_op_active (GtkMountOperation *operation,
+			  GParamSpec *pspec,
 			  ActivateParameters *parameters)
 {
+	gboolean is_active;
+
+	g_object_get (operation, "is-showing", &is_active, NULL);
+
 	if (is_active) {
-		if (parameters->timed_wait_active) {
-			eel_timed_wait_stop (cancel_activate_callback, parameters);
-			parameters->timed_wait_active = FALSE;
-		}
+		pause_activation_timed_cancel (parameters);
 	} else {
-		if (!parameters->timed_wait_active) {
-			activation_start_timed_cancel (parameters);
-		}
+		unpause_activation_timed_cancel (parameters);
 	}
 }
 
 static gboolean
-confirm_multiple_windows (GtkWindow *parent_window, int count)
+confirm_multiple_windows (GtkWindow *parent_window,
+			  int count,
+			  gboolean use_tabs)
 {
 	GtkDialog *dialog;
 	char *prompt;
@@ -984,8 +1004,13 @@ confirm_multiple_windows (GtkWindow *parent_window, int count)
 	}
 
 	prompt = _("Are you sure you want to open all files?");
-	detail = g_strdup_printf (ngettext("This will open %d separate window.",
-					   "This will open %d separate windows.", count), count);
+	if (use_tabs) {
+		detail = g_strdup_printf (ngettext("This will open %d separate tab.",
+						   "This will open %d separate tabs.", count), count);
+	} else {
+		detail = g_strdup_printf (ngettext("This will open %d separate window.",
+						   "This will open %d separate windows.", count), count);
+	}
 	dialog = eel_show_yes_no_dialog (prompt, detail, 
 					 GTK_STOCK_OK, GTK_STOCK_CANCEL,
 					 parent_window);
@@ -1000,6 +1025,8 @@ confirm_multiple_windows (GtkWindow *parent_window, int count)
 static void
 activate_files (ActivateParameters *parameters)
 {
+	NautilusWindowInfo *window_info;
+	NautilusWindowOpenFlags flags;
 	NautilusFile *file;
 	GList *launch_desktop_files;
 	GList *launch_files;
@@ -1037,7 +1064,9 @@ activate_files (ActivateParameters *parameters)
 			/* Special case for executable text files, since it might be
 			 * dangerous & unexpected to launch these.
 			 */
+			pause_activation_timed_cancel (parameters);
 			action = get_executable_text_file_action (parameters->parent_window, file);
+			unpause_activation_timed_cancel (parameters);
 		}
 
 		switch (action) {
@@ -1081,7 +1110,7 @@ activate_files (ActivateParameters *parameters)
 	if (parameters->activation_directory &&
 	    (launch_files != NULL || launch_in_terminal_files != NULL)) {
 		old_working_dir = g_get_current_dir ();
-		chdir (parameters->activation_directory);
+		g_chdir (parameters->activation_directory);
 		
 	}
 
@@ -1098,7 +1127,7 @@ activate_files (ActivateParameters *parameters)
 				    "directory view activate_callback launch_file window=%p: %s",
 				    parameters->parent_window, quoted_path);
 
-		nautilus_launch_application_from_command (screen, name, quoted_path, NULL, FALSE);
+		nautilus_launch_application_from_command (screen, name, quoted_path, FALSE, NULL);
 		g_free (name);
 		g_free (quoted_path);
 		g_free (executable_path);
@@ -1119,7 +1148,7 @@ activate_files (ActivateParameters *parameters)
 				    "directory view activate_callback launch_in_terminal window=%p: %s",
 				    parameters->parent_window, quoted_path);
 
-		nautilus_launch_application_from_command (screen, name, quoted_path, NULL, TRUE);
+		nautilus_launch_application_from_command (screen, name, quoted_path, TRUE, NULL);
 		g_free (name);
 		g_free (quoted_path);
 		g_free (executable_path);
@@ -1127,20 +1156,39 @@ activate_files (ActivateParameters *parameters)
 	}
 
 	if (old_working_dir != NULL) {
-		chdir (old_working_dir);
+		g_chdir (old_working_dir);
 		g_free (old_working_dir);
 	}
 
 	open_in_view_files = g_list_reverse (open_in_view_files);
 	count = g_list_length (open_in_view_files);
-	if (parameters->window_info != NULL &&
-	    confirm_multiple_windows (parameters->parent_window, count)) {
-		NautilusWindowOpenFlags flags;
 
-		flags = parameters->flags;
-		if (count > 1) {
+	flags = parameters->flags;
+	if (count > 1) {
+		if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_ENABLE_TABS) &&
+		    (parameters->flags & NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW) == 0) {
+			flags |= NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB;
+		} else {
 			flags |= NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW;
 		}
+	}
+
+	if (parameters->slot_info != NULL &&
+	    (!parameters->user_confirmation ||
+	     confirm_multiple_windows (parameters->parent_window, count,
+				       (flags & NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB) != 0))) {
+
+		if ((flags & NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB) != 0 &&
+		    eel_preferences_get_enum (NAUTILUS_PREFERENCES_NEW_TAB_POSITION) ==
+		    NAUTILUS_NEW_TAB_POSITION_AFTER_CURRENT_TAB) {
+			/* When inserting N tabs after the current one,
+			 * we first open tab N, then tab N-1, ..., then tab 0.
+			 * Each of them is appended to the current tab, i.e.
+			 * prepended to the list of tabs to open.
+			 */
+			open_in_view_files = g_list_reverse (open_in_view_files);
+		}
+
 
 		for (l = open_in_view_files; l != NULL; l = l->next) {
 			GFile *f;
@@ -1150,8 +1198,8 @@ activate_files (ActivateParameters *parameters)
 
 			uri = nautilus_file_get_activation_uri (file);
 			f = g_file_new_for_uri (uri);
-			nautilus_window_info_open_location (parameters->window_info,
-							    f, parameters->mode, flags, NULL);
+			nautilus_window_slot_info_open_location (parameters->slot_info,
+								 f, parameters->mode, flags, NULL);
 			g_object_unref (f);
 			g_free (uri);
 		}
@@ -1207,12 +1255,17 @@ activate_files (ActivateParameters *parameters)
 		g_free (error_message);
 	}
 
+	window_info = NULL;
+	if (parameters->slot_info != NULL) {
+		window_info = nautilus_window_slot_info_get_window (parameters->slot_info);
+	}
+
 	if (open_in_app_parameters != NULL ||
 	    unhandled_open_in_app_files != NULL) {
 		if ((parameters->flags & NAUTILUS_WINDOW_OPEN_FLAG_CLOSE_BEHIND) != 0 &&
-		    parameters->window_info != NULL && 
-		     nautilus_window_info_get_window_type (parameters->window_info) == NAUTILUS_WINDOW_SPATIAL) {
-			nautilus_window_info_close (parameters->window_info);
+		    window_info != NULL && 
+		     nautilus_window_info_get_window_type (window_info) == NAUTILUS_WINDOW_SPATIAL) {
+			nautilus_window_info_close (window_info);
 		}
 	}
 
@@ -1277,8 +1330,9 @@ activation_mount_not_mounted (ActivateParameters *parameters)
 
 	if (parameters->not_mounted != NULL) {
 		file = parameters->not_mounted->data;
-		mount_op = eel_mount_operation_new (parameters->parent_window);
-		g_signal_connect (mount_op, "active_changed", (GCallback)activate_mount_op_active, parameters);
+		mount_op = gtk_mount_operation_new (parameters->parent_window);
+		g_signal_connect_object (mount_op, "notify::is-showing",
+					 G_CALLBACK (activate_mount_op_active), parameters, 0);
 		location = nautilus_file_get_location (file);
 		g_file_mount_enclosing_volume (location, 0, mount_op, parameters->cancellable,
 					       activation_mount_not_mounted_callback, parameters);
@@ -1460,6 +1514,7 @@ activation_mountable_mounted (NautilusFile  *file,
 {
 	ActivateParameters *parameters = callback_data;
 	NautilusFile *target_file;
+	int position;
 
 	/* Remove from list of files that have to be mounted */
 	parameters->mountables = g_list_remove (parameters->mountables, file); 
@@ -1467,13 +1522,16 @@ activation_mountable_mounted (NautilusFile  *file,
 
 	if (error == NULL) {
 		/* Replace file with the result of the mount */
-		
 		target_file = nautilus_file_get (result_location);
 		
+		position = g_list_index (parameters->files, file);
+
 		parameters->files = g_list_remove (parameters->files, file); 
 		nautilus_file_unref (file);
 		
-		parameters->files = g_list_prepend (parameters->files, target_file);
+		parameters->files = g_list_insert (parameters->files,
+						   target_file,
+						   position);
 	} else {
 		/* Remove failed file */
 		
@@ -1511,8 +1569,9 @@ activation_mount_mountables (ActivateParameters *parameters)
 
 	if (parameters->mountables != NULL) {
 		file = parameters->mountables->data;
-		mount_op = eel_mount_operation_new (parameters->parent_window);
-		g_signal_connect (mount_op, "active_changed", (GCallback)activate_mount_op_active, parameters);
+		mount_op = gtk_mount_operation_new (parameters->parent_window);
+		g_signal_connect_object (mount_op, "notify::is-showing",
+					 G_CALLBACK (activate_mount_op_active), parameters, 0);
 		nautilus_file_mount (file,
 				     mount_op,
 				     parameters->cancellable,
@@ -1537,11 +1596,12 @@ activation_mount_mountables (ActivateParameters *parameters)
  **/
 void
 nautilus_mime_activate_files (GtkWindow *parent_window,
-			      NautilusWindowInfo *window_info,
+			      NautilusWindowSlotInfo *slot_info,
 			      GList *files,
 			      const char *launch_directory,
 			      NautilusWindowOpenMode mode,
-			      NautilusWindowOpenFlags flags)
+			      NautilusWindowOpenFlags flags,
+			      gboolean user_confirmation)
 {
 	ActivateParameters *parameters;
 	char *file_name;
@@ -1558,8 +1618,8 @@ nautilus_mime_activate_files (GtkWindow *parent_window,
 					   parent_window);
 
 	parameters = g_new0 (ActivateParameters, 1);
-	parameters->window_info = window_info;
-	g_object_add_weak_pointer (G_OBJECT (parameters->window_info), (gpointer *)&parameters->window_info);
+	parameters->slot_info = slot_info;
+	g_object_add_weak_pointer (G_OBJECT (parameters->slot_info), (gpointer *)&parameters->slot_info);
 	if (parent_window) {
 		parameters->parent_window = parent_window;
 		g_object_add_weak_pointer (G_OBJECT (parameters->parent_window), (gpointer *)&parameters->parent_window);
@@ -1569,6 +1629,7 @@ nautilus_mime_activate_files (GtkWindow *parent_window,
 	parameters->files = nautilus_file_list_copy (files);
 	parameters->mode = mode;
 	parameters->flags = flags;
+	parameters->user_confirmation = user_confirmation;
 
 	file_count = g_list_length (files);
 	if (file_count == 1) {
@@ -1610,7 +1671,7 @@ nautilus_mime_activate_files (GtkWindow *parent_window,
 
 void
 nautilus_mime_activate_file (GtkWindow *parent_window,
-			     NautilusWindowInfo *window_info,
+			     NautilusWindowSlotInfo *slot_info,
 			     NautilusFile *file,
 			     const char *launch_directory,
 			     NautilusWindowOpenMode mode,
@@ -1621,6 +1682,6 @@ nautilus_mime_activate_file (GtkWindow *parent_window,
 	g_return_if_fail (NAUTILUS_IS_FILE (file));
 
 	files = g_list_prepend (NULL, file);
-	nautilus_mime_activate_files (parent_window, window_info, files, launch_directory, mode, flags);
+	nautilus_mime_activate_files (parent_window, slot_info, files, launch_directory, mode, flags, FALSE);
 	g_list_free (files);
 }
