@@ -44,19 +44,11 @@
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
 #include <eel/eel-xml-extensions.h>
-#include <librsvg/rsvg.h>
 #include <libxml/parser.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 #include <gio/gio.h>
-#include <libgnome/gnome-util.h>
-#include <libgnome/gnome-help.h>
-#include <libgnomeui/gnome-color-picker.h>
-#include <libgnomeui/gnome-icon-entry.h>
-#include <libgnomeui/gnome-help.h>
-#include <libgnomeui/gnome-stock-icons.h>
-#include <libgnomeui/gnome-uidefs.h>
 #include <libnautilus-private/nautilus-customization-data.h>
 #include <libnautilus-private/nautilus-directory.h>
 #include <libnautilus-private/nautilus-emblem-utils.h>
@@ -103,7 +95,7 @@ struct NautilusPropertyBrowserDetails {
 	
 	GtkWidget *keyword;
 	GtkWidget *emblem_image;
-	GtkWidget *file_entry;
+	GtkWidget *image_button;
 	
 	GtkWidget *color_picker;
 	GtkWidget *color_name;
@@ -115,6 +107,7 @@ struct NautilusPropertyBrowserDetails {
 	char *dragged_file;
 	char *drag_type;
 	char *image_path;
+	char *filename;
 	
 	NautilusPropertyType category_type;
 	
@@ -617,7 +610,7 @@ nautilus_property_browser_drag_data_get (GtkWidget *widget,
 			
 			/* handle the "reset" case as an image */
 			if (eel_strcmp (property_browser->details->dragged_file, RESET_IMAGE_NAME) != 0) {
-				eel_gdk_color_parse (property_browser->details->dragged_file, &color);
+				gdk_color_parse (property_browser->details->dragged_file, &color);
 
 				colorArray[0] = color.red;
 				colorArray[1] = color.green;
@@ -749,13 +742,10 @@ make_drag_image (NautilusPropertyBrowser *property_browser, const char* file_nam
 		g_free (user_directory);	
 	}
 	
-	orig_pixbuf = gdk_pixbuf_new_from_file (image_file_name, NULL);
-	
-	if (orig_pixbuf == NULL) {
-		orig_pixbuf = rsvg_pixbuf_from_file_at_max_size (image_file_name,
-								 MAX_ICON_WIDTH, MAX_ICON_HEIGHT,
-								 NULL);
-	}
+	orig_pixbuf = gdk_pixbuf_new_from_file_at_scale (image_file_name,
+							 MAX_ICON_WIDTH, MAX_ICON_HEIGHT,
+							 TRUE,
+							 NULL);
 	
 	g_free (image_file_name);
 
@@ -791,11 +781,11 @@ make_color_drag_image (NautilusPropertyBrowser *property_browser, const char *co
 
 	color_square = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, COLOR_SQUARE_SIZE, COLOR_SQUARE_SIZE);
 	
-	eel_gdk_color_parse (color_spec, &color);
+	gdk_color_parse (color_spec, &color);
 	color.red >>= 8;
 	color.green >>= 8;
 	color.blue >>= 8;
-	
+ 
 	pixels = gdk_pixbuf_get_pixels (color_square);
 	stride = gdk_pixbuf_get_rowstride (color_square);
 	
@@ -1005,13 +995,75 @@ nautilus_property_browser_remove_element (NautilusPropertyBrowser *property_brow
 	}
 }
 
+static void
+update_preview_cb (GtkFileChooser *fc,
+		   GtkImage *preview)
+{
+	char *filename;
+	GdkPixbuf *pixbuf;
+
+	filename = gtk_file_chooser_get_preview_filename (fc);
+	if (filename) {
+		pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
+
+		gtk_file_chooser_set_preview_widget_active (fc, pixbuf != NULL);
+		
+		if (pixbuf) {
+			gtk_image_set_from_pixbuf (preview, pixbuf);
+			g_object_unref (pixbuf);
+		}
+		
+		g_free (filename);
+	}
+}
+
+static void
+icon_button_clicked_cb (GtkButton *b,
+			NautilusPropertyBrowser *browser)
+{
+	GtkWidget *dialog;
+	GtkFileFilter *filter;
+	GtkWidget *preview;
+	int res;
+
+	dialog = gtk_file_chooser_dialog_new (_("Select an Image File for the New Emblem"),
+					      GTK_WINDOW (browser),
+					      GTK_FILE_CHOOSER_ACTION_OPEN, 
+					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					      GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+					      NULL);
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog),
+					     DATADIR "/pixmaps");
+	filter = gtk_file_filter_new ();
+	gtk_file_filter_add_pixbuf_formats (filter);
+	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), filter);
+
+	preview = gtk_image_new ();
+	gtk_file_chooser_set_preview_widget (GTK_FILE_CHOOSER (dialog),
+					     preview);
+	g_signal_connect (dialog, "update-preview",
+			  G_CALLBACK (update_preview_cb), preview);
+
+	res = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	if (res == GTK_RESPONSE_ACCEPT) {
+		/* update the image */
+		g_free (browser->details->filename);
+		browser->details->filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+		gtk_image_set_from_file (GTK_IMAGE (browser->details->image_button), browser->details->filename);
+	}
+
+	gtk_widget_destroy (dialog);
+}
+
 /* here's where we create the emblem dialog */
 static GtkWidget*
 nautilus_emblem_dialog_new (NautilusPropertyBrowser *property_browser)
 {
-	GtkWidget *hbox;
 	GtkWidget *widget;
+	GtkWidget *button;
 	GtkWidget *dialog;
+	GtkWidget *label;
 	GtkWidget *table = gtk_table_new(2, 2, FALSE);
 
 	dialog = gtk_dialog_new_with_buttons (_("Create a New Emblem"),
@@ -1051,31 +1103,29 @@ nautilus_emblem_dialog_new (NautilusPropertyBrowser *property_browser)
 				       GTK_WIDGET (property_browser->details->keyword));
 
 	/* default image is the generic emblem */
-	g_free(property_browser->details->image_path);		
+	g_free (property_browser->details->image_path);		
 	property_browser->details->image_path = g_build_filename (NAUTILUS_PIXMAPDIR, "emblems.png", NULL);
 	
-	/* set up a gnome icon entry to pick the image file */
-	widget = gtk_label_new_with_mnemonic (_("_Image:"));
-	gtk_misc_set_alignment (GTK_MISC (widget), 0, 0.5);
-	gtk_widget_show(widget);
-	gtk_table_attach(GTK_TABLE(table), widget, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
+	/* set up a file chooser to pick the image file */
+	label = gtk_label_new_with_mnemonic (_("_Image:"));
+	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+	gtk_widget_show (label);
+	gtk_table_attach (GTK_TABLE(table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_widget_show (hbox);
+	widget = gtk_hbox_new (FALSE, 0);
+	gtk_widget_show (widget);
 
-	property_browser->details->file_entry = gnome_icon_entry_new (NULL, _("Select an Image File for the New Emblem"));
-	gnome_icon_entry_set_pixmap_subdir (GNOME_ICON_ENTRY(property_browser->details->file_entry),
-						DATADIR "/pixmaps");
-	gnome_icon_entry_set_filename (GNOME_ICON_ENTRY(property_browser->details->file_entry),
-				       property_browser->details->image_path);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (widget),
-				       GTK_WIDGET (property_browser->details->file_entry));
+	button = gtk_button_new ();
+	property_browser->details->image_button = gtk_image_new_from_file (property_browser->details->image_path);
+	gtk_button_set_image (GTK_BUTTON (button), property_browser->details->image_button);
+	g_signal_connect (button, "clicked", G_CALLBACK (icon_button_clicked_cb),
+			  property_browser);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), button);
+
+	gtk_widget_show (button);
+	gtk_table_attach (GTK_TABLE (table), widget, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
+	gtk_box_pack_start (GTK_BOX (widget), button, FALSE, FALSE, 0);
 
-	gtk_widget_show(property_browser->details->file_entry);
-	gtk_table_attach(GTK_TABLE(table), hbox, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
-	gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (property_browser->details->file_entry), FALSE, FALSE, 0);
-	
-	gnome_icon_entry_set_filename (GNOME_ICON_ENTRY (property_browser->details->file_entry), property_browser->details->image_path);	
 	return dialog;
 }
 
@@ -1121,93 +1171,79 @@ nautilus_color_selection_dialog_new (NautilusPropertyBrowser *property_browser)
 	widget = gtk_label_new_with_mnemonic(_("Color _value:"));
 	gtk_widget_show(widget);
 	gtk_table_attach(GTK_TABLE(table), widget, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
- 
-	/* set up a gnome file entry to pick the image file */
-	property_browser->details->color_picker = gnome_color_picker_new ();
+
+	property_browser->details->color_picker = gtk_color_button_new ();
 	gtk_widget_show (property_browser->details->color_picker);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (widget), property_browser->details->color_picker);
 
 	gtk_table_attach(GTK_TABLE(table), property_browser->details->color_picker, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
-		
-	
+
 	return dialog;
 }
 
 /* add the newly selected file to the browser images */
 static void
-add_pattern_to_browser (const char *path_name, gpointer *data)
+add_pattern_to_browser (GtkDialog *dialog, gint response_id, gpointer *data)
 {
-	char *directory_path, *source_file_name, *destination_name;
-	char *path_uri, *basename;
+	char *directory_path, *destination_name;
+	char *basename;
 	char *user_directory;	
-	GFile *src, *dest;
+	GFile *dest, *selected;
 	
 	NautilusPropertyBrowser *property_browser = NAUTILUS_PROPERTY_BROWSER (data);
 
-	/* make sure that it's a valid path */
-	if (path_name == NULL || path_name[0] != '/') {
-		char *message;
-		char *detail;
-		if (path_name != NULL) {
-			message = g_strdup_printf (_("Sorry, but \"%s\" is not a valid file name."), path_name);
-			detail = _("Please check the spelling and try again.");
-		} else {
-			message = g_strdup (_("Sorry, but you did not supply a valid file name."));
-			detail = _("Please try again.");
-		}
-		eel_show_error_dialog (message, detail, GTK_WINDOW (property_browser));
-		g_free (message);
+	if (response_id != GTK_RESPONSE_ACCEPT) {
+		gtk_widget_hide (GTK_WIDGET (dialog));
 		return;
 	}
 	
-	/* fetch the mime type and make sure that the file is an image */
-	path_uri = g_filename_to_uri (path_name, NULL, NULL);	
-
+	selected = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (dialog));
+	
 	/* don't allow the user to change the reset image */
-	basename = g_path_get_basename (path_name);
+	basename = g_file_get_basename (selected);
 	if (basename && eel_strcmp (basename, RESET_IMAGE_NAME) == 0) {
 		eel_show_error_dialog (_("Sorry, but you cannot replace the reset image."), 
 		                       _("Reset is a special image that cannot be deleted."), 
 		                       NULL);
-		g_free (path_uri);
+		g_object_unref (selected);
 		g_free (basename);
 		return;
 	}
 		
-	g_free (path_uri);	
-	g_free (basename);
 		
 	user_directory = nautilus_get_user_directory ();
 		
 	/* copy the image file to the patterns directory */
 	directory_path = g_build_filename (user_directory, "patterns", NULL);
 	g_free (user_directory);
-	source_file_name = strrchr (path_name, '/');
-	destination_name = g_build_filename (directory_path, source_file_name + 1, NULL);
+	destination_name = g_build_filename (directory_path, basename, NULL);
 
 	/* make the directory if it doesn't exist */
 	if (!g_file_test (directory_path, G_FILE_TEST_EXISTS)) {
 		g_mkdir_with_parents (directory_path, 0775);
 	}
 		
+	dest = g_file_new_for_path (destination_name);
+	
+	g_free (destination_name);
 	g_free (directory_path);
 
-	src = g_file_new_for_path (path_name);
-	dest = g_file_new_for_path (destination_name);
-	if (!g_file_copy (src, dest,
+	if (!g_file_copy (selected, dest,
 			  0,
 			  NULL, NULL, NULL, NULL)) {
-		char *message = g_strdup_printf (_("Sorry, but the pattern %s could not be installed."), path_name);
+		char *message = g_strdup_printf (_("Sorry, but the pattern %s could not be installed."), basename);
 		eel_show_error_dialog (message, NULL, GTK_WINDOW (property_browser));
 		g_free (message);
 	}
-	g_object_unref (src);
+	g_object_unref (selected);
 	g_object_unref (dest);
+	g_free (basename);
 	
-	g_free (destination_name);
 	
 	/* update the property browser's contents to show the new one */
 	nautilus_property_browser_update_contents (property_browser);
+
+	gtk_widget_hide (GTK_WIDGET (dialog));
 }
 
 /* here's where we initiate adding a new pattern by putting up a file selector */
@@ -1215,16 +1251,40 @@ add_pattern_to_browser (const char *path_name, gpointer *data)
 static void
 add_new_pattern (NautilusPropertyBrowser *property_browser)
 {
+	GtkWidget *dialog;
+	GtkFileFilter *filter;
+	GtkWidget *preview;
+	
 	if (property_browser->details->patterns_dialog) {
 		gtk_window_present (GTK_WINDOW (property_browser->details->patterns_dialog));
 	} else {
-		property_browser->details->patterns_dialog = 
-			eel_gnome_icon_selector_new (_("Select an Image File to Add as a Pattern"),
-				DATADIR "/nautilus/patterns/",
-				GTK_WINDOW (property_browser),
-				(EelIconSelectionFunction) add_pattern_to_browser,
-				property_browser);						   
+		property_browser->details->patterns_dialog = dialog = 
+			gtk_file_chooser_dialog_new (_("Select an Image File to Add as a Pattern"),
+						     GTK_WINDOW (property_browser),
+						     GTK_FILE_CHOOSER_ACTION_OPEN, 
+						     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+						     GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+						     NULL);
+		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog),
+						     DATADIR "/nautilus/patterns/");
+		filter = gtk_file_filter_new ();
+		gtk_file_filter_add_pixbuf_formats (filter);
+		gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), filter);
 
+		gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (dialog), FALSE);
+		
+		preview = gtk_image_new ();
+		gtk_file_chooser_set_preview_widget (GTK_FILE_CHOOSER (dialog),
+						     preview);
+		g_signal_connect (dialog, "update-preview",
+				  G_CALLBACK (update_preview_cb), preview);
+		
+		g_signal_connect (dialog, "response",
+				  G_CALLBACK (add_pattern_to_browser),
+				  property_browser);
+
+		gtk_widget_show (GTK_WIDGET (dialog));
+		
 		if (property_browser->details->patterns_dialog)
 			eel_add_weak_pointer (&property_browser->details->patterns_dialog);
 	}
@@ -1284,20 +1344,17 @@ add_color_to_file (NautilusPropertyBrowser *property_browser, const char *color_
 static void
 add_color_to_browser (GtkWidget *widget, gint which_button, gpointer *data)
 {
-	char color_spec[8];
+	char * color_spec;
 	const char *color_name;
 	char *stripped_color_name;
 
-	gdouble color[4];
 	NautilusPropertyBrowser *property_browser = NAUTILUS_PROPERTY_BROWSER (data);
 
 	if (which_button == GTK_RESPONSE_OK) {
-		gnome_color_picker_get_d (GNOME_COLOR_PICKER (property_browser->details->color_picker), &color[0], &color[1], &color[2], &color[3]);		
-		g_snprintf (color_spec, sizeof (color_spec),
-			 "#%02X%02X%02X",
-			 (guint) (color[0] * 255.0 + 0.5),
-			 (guint) (color[1] * 255.0 + 0.5),
-			 (guint) (color[2] * 255.0 + 0.5));
+		GdkColor color;
+
+		gtk_color_button_get_color (GTK_COLOR_BUTTON (property_browser->details->color_picker), &color);
+		color_spec = gdk_color_to_string (&color);
 
 		color_name = gtk_entry_get_text (GTK_ENTRY (property_browser->details->color_name));
 		stripped_color_name = g_strstrip (g_strdup (color_name));
@@ -1311,6 +1368,7 @@ add_color_to_browser (GtkWidget *widget, gint which_button, gpointer *data)
 			nautilus_property_browser_update_contents(property_browser);
 		}
 		g_free (stripped_color_name);
+		g_free (color_spec);
 	}
 	
 	gtk_widget_destroy(property_browser->details->colors_dialog);
@@ -1331,17 +1389,16 @@ show_color_selection_window (GtkWidget *widget, gpointer *data)
 	property_browser->details->colors_dialog = nautilus_color_selection_dialog_new (property_browser);		
 
 	/* set the color to the one picked by the selector */
-	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (property_browser->details->color_picker), color.red, color.green, color.blue, 1.0);
-	
+	gtk_color_button_set_color (GTK_COLOR_BUTTON (property_browser->details->color_picker), &color);
+
 	/* connect the signals to the new dialog */
-	
+
 	eel_add_weak_pointer (&property_browser->details->colors_dialog);
 
 	g_signal_connect_object (property_browser->details->colors_dialog, "response",
 				 G_CALLBACK (add_color_to_browser), property_browser, 0);
 	gtk_window_set_position (GTK_WINDOW (property_browser->details->colors_dialog), GTK_WIN_POS_MOUSE);
 	gtk_widget_show (GTK_WIDGET(property_browser->details->colors_dialog));
-
 }
 
 
@@ -1384,24 +1441,23 @@ emblem_dialog_clicked (GtkWidget *dialog, int which_button, NautilusPropertyBrow
 	if (which_button == GTK_RESPONSE_OK) {
 
 		/* update the image path from the file entry */
-		if (property_browser->details->file_entry) {
-			emblem_path = gnome_icon_entry_get_filename (GNOME_ICON_ENTRY (property_browser->details->file_entry));
-			if (emblem_path) {
-				emblem_file = g_file_new_for_path (emblem_path);
-				if (ensure_file_is_image (emblem_file)) {
-					g_free (property_browser->details->image_path);
-					property_browser->details->image_path = emblem_path;				
-				} else {
-					char *message = g_strdup_printf
-						(_("Sorry, but \"%s\" is not a usable image file."), emblem_path);
-					eel_show_error_dialog (_("The file is not an image."), message, GTK_WINDOW (property_browser));
-					g_free (message);
-					g_free (emblem_path);
-					g_object_unref (emblem_file);
-					return;
-				}
+		if (property_browser->details->filename) {
+			emblem_path = property_browser->details->filename;
+			emblem_file = g_file_new_for_path (emblem_path);
+			if (ensure_file_is_image (emblem_file)) {
+				g_free (property_browser->details->image_path);
+				property_browser->details->image_path = emblem_path;
+			} else {
+				char *message = g_strdup_printf
+					(_("Sorry, but \"%s\" is not a usable image file."), emblem_path);
+				eel_show_error_dialog (_("The file is not an image."), message, GTK_WINDOW (property_browser));
+				g_free (message);
+				g_free (emblem_path);
+				emblem_path = NULL;
 				g_object_unref (emblem_file);
+				return;
 			}
+			g_object_unref (emblem_file);
 		}
 
 		emblem_file = g_file_new_for_path (property_browser->details->image_path);
@@ -1441,7 +1497,7 @@ emblem_dialog_clicked (GtkWidget *dialog, int which_button, NautilusPropertyBrow
 	
 	property_browser->details->keyword = NULL;
 	property_browser->details->emblem_image = NULL;
-	property_browser->details->file_entry = NULL;
+	property_browser->details->filename = NULL;
 }
 
 /* here's the routine to add a new emblem, by putting up an emblem dialog */
@@ -1515,9 +1571,9 @@ help_button_callback (GtkWidget *widget, GtkWidget *property_browser)
 	GError *error = NULL;
 	GtkWidget *dialog;
 
-	gnome_help_display_desktop_on_screen (
-		NULL, "user-guide", "user-guide.xml", "gosnautilus-50",
-		gtk_window_get_screen (GTK_WINDOW (property_browser)), &error);
+	gtk_show_uri (gtk_widget_get_screen (property_browser),
+		      "ghelp:user-guide#gosnautilus-50",
+		      gtk_get_current_event_time (), &error);
 
 	if (error) {
 		dialog = gtk_message_dialog_new (GTK_WINDOW (property_browser),
